==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/shells/base/ibgwidgethelpbrowsersubject.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  HTML Browser widget subject
//
#ifndef IBGWIDGETHELPBROWSERSUBJECT_H
#define IBGWIDGETHELPBROWSERSUBJECT_H


#include "ibgwidgetsubject.h"


class iImage;
class iString;

class iggWidgetHelpBrowser;


class ibgWidgetHelpBrowserSubject : public ibgWidgetSubject
{

public:

	virtual ~ibgWidgetHelpBrowserSubject();

	virtual void SetText(const iString &text) = 0;
	virtual iString GetText() const = 0;

	virtual void AddImage(const iString &name, const iImage &image) = 0;

protected:

	ibgWidgetHelpBrowserSubject(iggWidgetHelpBrowser *owner);

	void OnLinkFollowedBody(const char *tag);
	//void OnMousePressBody(int para, int index);
	//void OnMouseReleaseBody(int para, int index);

	iggWidgetHelpBrowser *mConcreteOwner;
};

#endif  //  IBGWIDGETHELPBROWSERSUBJECT_H

==> ifrit_3.3.2.orig.tar.gz: ifrit-3.3.2/shells/base/ibgwidgethelpbrowsersubject.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  HTML Browser widget subject
//
#ifndef IBGWIDGETHELPBROWSERSUBJECT_H
#define IBGWIDGETHELPBROWSERSUBJECT_H


#include "ibgwidgetsubject.h"


class iImage;
class iString;

class iggWidgetHelpBrowser;


class ibgWidgetHelpBrowserSubject : public ibgWidgetSubject
{

public:

	virtual ~ibgWidgetHelpBrowserSubject();

	virtual void SetText(const iString &text) = 0;
	virtual iString GetText() const = 0;

	virtual void AddImage(const iString &name, const iImage &image) = 0;

protected:

	ibgWidgetHelpBrowserSubject(iggWidgetHelpBrowser *owner);

	void OnLinkFollowedBody(const char *tag);
	//void OnMousePressBody(int line, int index);
	//void OnMouseReleaseBody(int line, int index);

	iggWidgetHelpBrowser *mConcreteOwner;
};

#endif  //  IBGWIDGETHELPBROWSERSUBJECT_H
